==> hoteldruid-mod-nl_2.2.1-1.zip: nl/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "a":  					$messaggio = "to"; break;
case "Il nome verrà cambiato da":  		$messaggio = "De naam wordt gewijzigd van"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "Geslacht wordt gewijzigd naar "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "Geboortedatum wordt gewijzigd naar"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Telefoonnummer wordt gewijzigd van"; break;
case "La via  verrà cambiata da":  		$messaggio = "De straatnaam wordt gewijzigd van"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Het huisnummer wordt gewijzigd van"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "De plaatsnaam wordt gewijzigd van"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "De postcode wordt gewijzigd van"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Het faxnummer wordt gewijzigd van"; break;
case "L' email verrà cambiata da":  		$messaggio = "Het emailadres wordt gewijzigd van"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "Het GSM nummer wordt gewijzigd van"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "Het tweede telefoonnummer wordt gewijzigd van"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "Het <b>commentaar</b> wordt gewijzigd"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "De <b>naam</b> wordt gewist"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "e <b>geboortedatum</b> wordt gewist"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "Het <b>telefoonnummer</b> wordt gewist"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "e <b>straatnaam</b> wordt gewist"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "Het <b>huisnummer</b> wrodt gewist"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "De <b>postcode</b> wordt gewist"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "Het <b>faxnummer</b> wordt gewist"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "Het <b>emailadres</b> wordt gewist"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "Het<b>GSMnummer</b> wordt gewist"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "Het <b>tweede telefoonnummer</b> wordt gewist"; break;
case "Continua":  				$messaggio = "Ge verder"; break;
case "Il cliente":  				$messaggio = "Gast"; break;
case "è stato modificato":  			$messaggio = "is gewijzigd"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Modifica i dati del cliente":  		$messaggio = "Wijzig gegevens van gast"; break;
case "Cognome":  				$messaggio = "Achternaam"; break;
case "cambia in":  				$messaggio = "wijzigd naar"; break;
case "Nome":  					$messaggio = "Naam"; break;
case "cancella":  				$messaggio = "verwijder"; break;
case "Sesso":  					$messaggio = "Geslacht"; break;
case "Data di nascita":  			$messaggio = "Geboortedatum"; break;
case "Telefono":  				$messaggio = "Telefoon"; break;
case "Via":  					$messaggio = "Straat"; break;
case "Piazza":  				$messaggio = "Plein"; break;
case "Piazzale":  				$messaggio = "Boulevaar"; break;
case "Vicolo":  				$messaggio = "weg"; break;
case "Numero civico":  				$messaggio = "Straat nummer"; break;
case "CAP":  					$messaggio = "Postcode"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "2° telefono":  				$messaggio = "GSM"; break;
case "3° telefono":  				$messaggio = "2de telefoon"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reservering van gast"; break;
case "nel":  					$messaggio = "in"; break;
case "Cognome_del_cliente":  			$messaggio = "Achternaam_gast"; break;
case "Data_iniziale":  				$messaggio = "Begin_datum"; break;
case "Data_finale":  				$messaggio = "Eind_datum"; break;
case "Tariffa_completa":  			$messaggio = "Gehele_tarief"; break;
case "Caparra":  				$messaggio = "Deposito"; break;
case "Pagato":  				$messaggio = "Betaald"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Pers":  					$messaggio = "Mensen"; break;
case "Inserito da":  				$messaggio = "Ingevoegd door"; break;
case "Si considererà l'utente":  		$messaggio = "Gebruiker"; break;
case "come colui che ha inserito il cliente":	$messaggio = "wordt gezien als degene die de gast heeft ingevoegd"; break;
case "Cliente cancellato":  			$messaggio = "Gast gewist"; break;
case "Cancella il cliente":  			$messaggio = "Wis gast"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "De gast kan niet gewist worden omdat deze nog steeds gekoppeld is aan een reservering"; break;
case "NO":  					$messaggio = "NEE"; break;
case "SI":  					$messaggio = "JA"; break;
case "Scadenza documento":  			$messaggio = "Verloopdatum document"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Het document wordt gewijzigd van"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "De verloopdatum van het document wordt gewijzigd van"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "Het <b>document</b> wordt gewist"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "De <b>verloopdatum van document</b> wordt gewist"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "Il cognome verrà cambiato da":  		$messaggio = "The surname will be changed from"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "The nation of residence will be changed from"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "The <b>city of residence</b> will be deleted"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "The <b>nation of residence</b> will be deleted"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Città di residenza":  			$messaggio = "City of residence"; break;
case "Nazione di residenza":  			$messaggio = "Nation of residence"; break;
case "Email":  					$messaggio = "Email"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\">delete</div> client"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Region of residence"; break;
case "Documento":  				$messaggio = "Document"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "The region of residence will be changed from"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "The <b>region of residence</b> will be deleted"; break;
case "Cittadinanza":  				$messaggio = "Nationality"; break;
case "Nazione di nascita":  			$messaggio = "Nation of birth"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Region of birth"; break;
case "Città di nascita":  			$messaggio = "City of birth"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "Nazione di rilascio":  			$messaggio = "Releasing nation"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "The nationality will be changed from"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "The nation of birth will be changed from"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "The region of birth will be changed from"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "The city of birth will be changed from"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "The nation releasing the document will be changed from"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "The <b>nationality</b> will be deleted"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>nation of birth</b> will be deleted"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>region of birth</b> will be deleted"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>city of birth</b> will be deleted"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>nation releasing the document</b> will be deleted"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "The fiscal code will be changed from"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.zip: nl/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "a":  					$messaggio = "to"; break;
case "Il nome verrà cambiato da":  		$messaggio = "De naam wordt gewijzigd van"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "Geslacht wordt gewijzigd naar "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "Geboortedatum wordt gewijzigd naar"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Telefoonnummer wordt gewijzigd van"; break;
case "La via  verrà cambiata da":  		$messaggio = "De straatnaam wordt gewijzigd van"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Het huisnummer wordt gewijzigd van"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "De plaatsnaam wordt gewijzigd van"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "De postcode wordt gewijzigd van"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Het faxnummer wordt gewijzigd van"; break;
case "L' email verrà cambiata da":  		$messaggio = "Het emailadres wordt gewijzigd van"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "Het GSM nummer wordt gewijzigd van"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "Het tweede telefoonnummer wordt gewijzigd van"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "Het <b>commentaar</b> wordt gewijzigd"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "De <b>naam</b> wordt gewist"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "e <b>geboortedatum</b> wordt gewist"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "Het <b>telefoonnummer</b> wordt gewist"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "e <b>straatnaam</b> wordt gewist"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "Het <b>huisnummer</b> wrodt gewist"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "De <b>postcode</b> wordt gewist"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "Het <b>faxnummer</b> wordt gewist"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "Het <b>emailadres</b> wordt gewist"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "Het<b>GSMnummer</b> wordt gewist"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "Het <b>tweede telefoonnummer</b> wordt gewist"; break;
case "Continua":  				$messaggio = "Ge verder"; break;
case "Il cliente":  				$messaggio = "Gast"; break;
case "è stato modificato":  			$messaggio = "is gewijzigd"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Modifica i dati del cliente":  		$messaggio = "Wijzig gegevens van gast"; break;
case "Cognome":  				$messaggio = "Achternaam"; break;
case "cambia in":  				$messaggio = "wijzigd naar"; break;
case "Nome":  					$messaggio = "Naam"; break;
case "cancella":  				$messaggio = "verwijder"; break;
case "Sesso":  					$messaggio = "Geslacht"; break;
case "Data di nascita":  			$messaggio = "Geboortedatum"; break;
case "Telefono":  				$messaggio = "Telefoon"; break;
case "Via":  					$messaggio = "Straat"; break;
case "Piazza":  				$messaggio = "Plein"; break;
case "Piazzale":  				$messaggio = "Boulevaar"; break;
case "Vicolo":  				$messaggio = "weg"; break;
case "Numero civico":  				$messaggio = "Straat nummer"; break;
case "CAP":  					$messaggio = "Postcode"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "2° telefono":  				$messaggio = "GSM"; break;
case "3° telefono":  				$messaggio = "2de telefoon"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reservering van gast"; break;
case "nel":  					$messaggio = "in"; break;
case "Cognome_del_cliente":  			$messaggio = "Achternaam_gast"; break;
case "Data_iniziale":  				$messaggio = "Begin_datum"; break;
case "Data_finale":  				$messaggio = "Eind_datum"; break;
case "Tariffa_completa":  			$messaggio = "Gehele_tarief"; break;
case "Caparra":  				$messaggio = "Deposito"; break;
case "Pagato":  				$messaggio = "Betaald"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Pers":  					$messaggio = "Mensen"; break;
case "Inserito da":  				$messaggio = "Ingevoegd door"; break;
case "Si considererà l'utente":  		$messaggio = "Gebruiker"; break;
case "come colui che ha inserito il cliente":	$messaggio = "wordt gezien als degene die de gast heeft ingevoegd"; break;
case "Cliente cancellato":  			$messaggio = "Gast gewist"; break;
case "Cancella il cliente":  			$messaggio = "Wis gast"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "De gast kan niet gewist worden omdat deze nog steeds gekoppeld is aan een reservering"; break;
case "NO":  					$messaggio = "NEE"; break;
case "SI":  					$messaggio = "JA"; break;
case "Scadenza documento":  			$messaggio = "Verloopdatum document"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Het document wordt gewijzigd van"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "De verloopdatum van het document wordt gewijzigd van"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "Het <b>document</b> wordt gewist"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "De <b>verloopdatum van document</b> wordt gewist"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
case "Il cognome verrà cambiato da":  		$messaggio = "The surname will be changed from"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "The nation of residence will be changed from"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "The <b>city of residence</b> will be deleted"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "The <b>nation of residence</b> will be deleted"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Città di residenza":  			$messaggio = "City of residence"; break;
case "Nazione di residenza":  			$messaggio = "Nation of residence"; break;
case "Email":  					$messaggio = "Email"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\">delete</div> client"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Region of residence"; break;
case "Documento":  				$messaggio = "Document"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "The region of residence will be changed from"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "The <b>region of residence</b> will be deleted"; break;
case "Cittadinanza":  				$messaggio = "Nationality"; break;
case "Nazione di nascita":  			$messaggio = "Nation of birth"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Region of birth"; break;
case "Città di nascita":  			$messaggio = "City of birth"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "Nazione di rilascio":  			$messaggio = "Releasing nation"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "The nationality will be changed from"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "The nation of birth will be changed from"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "The region of birth will be changed from"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "The city of birth will be changed from"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "The nation releasing the document will be changed from"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "The <b>nationality</b> will be deleted"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>nation of birth</b> will be deleted"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>region of birth</b> will be deleted"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>city of birth</b> will be deleted"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>nation releasing the document</b> will be deleted"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "The fiscal code will be changed from"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
